@@ -31,7 +31,7 @@ double get_norm(SEXP obj, const char *typstr)
     int *dims = INTEGER(GET_SLOT(obj, Matrix_DimSym));
     double *work = (double *) NULL;
 
-    typnm[0] = norm_type(typstr);
+    typnm[0] = La_norm_type(typstr);
     if (*typnm == 'I') {
 	work = (double *) R_alloc(dims[0], sizeof(double));
     }
@@ -51,7 +51,7 @@ SEXP dtrMatrix_rcond(SEXP obj, SEXP type)
     int *dims = INTEGER(GET_SLOT(obj, Matrix_DimSym)), info;
     double rcond;
 
-    typnm[0] = rcond_type(CHAR(asChar(type)));
+    typnm[0] = La_rcond_type(CHAR(asChar(type)));
     F77_CALL(dtrcon)(typnm, uplo_P(obj), diag_P(obj), dims,
 		     REAL(GET_SLOT(obj, Matrix_xSym)), dims, &rcond,
 		     (double *) R_alloc(3*dims[0], sizeof(double)),
@@ -101,11 +101,12 @@ SEXP dtrMatrix_matrix_mm(SEXP a, SEXP b, SEXP right)
 	error(_("dtrMatrix in %*% must be square"));
     if ((rt && adims[0] != n) || (!rt && adims[1] != m))
 	error(_("Matrices are not conformable for multiplication"));
-    if (m < 1 || n < 1)
-	error(_("Matrices with zero extents cannot be multiplied"));
-    F77_CALL(dtrmm)(rt ? "R" : "L", uplo_P(a), "N", diag_P(a), &m, &n, &one,
-		    REAL(GET_SLOT(a, Matrix_xSym)), adims,
-		    REAL(GET_SLOT(val, Matrix_xSym)), &m);
+    if (m < 1 || n < 1) {
+/* 	error(_("Matrices with zero extents cannot be multiplied")); */
+    } else
+	F77_CALL(dtrmm)(rt ? "R" : "L", uplo_P(a), "N", diag_P(a), &m, &n, &one,
+			REAL(GET_SLOT(a, Matrix_xSym)), adims,
+			REAL(GET_SLOT(val, Matrix_xSym)), &m);
     UNPROTECT(1);
     return val;
 }
@@ -160,11 +161,12 @@ SEXP dtrMatrix_dgeMatrix_mm_R(SEXP a, SEXP b)
 
     if (bdims[0] != k)
 	error(_("Matrices are not conformable for multiplication"));
-    if (m < 1 || n < 1 || k < 1)
-	error(_("Matrices with zero extents cannot be multiplied"));
-    F77_CALL(dtrmm)("R", uplo_P(a), "N", diag_P(a), adims, bdims+1, &one,
-		    REAL(GET_SLOT(a, Matrix_xSym)), adims,
-		    REAL(GET_SLOT(val, Matrix_xSym)), bdims);
+    if (m < 1 || n < 1 || k < 1) {
+/* 	error(_("Matrices with zero extents cannot be multiplied")); */
+    } else
+	F77_CALL(dtrmm)("R", uplo_P(a), "N", diag_P(a), adims, bdims+1, &one,
+			REAL(GET_SLOT(a, Matrix_xSym)), adims,
+			REAL(GET_SLOT(val, Matrix_xSym)), bdims);
     UNPROTECT(1);
     return val;
 }
